@@ -1,29 +1,34 @@
-#' Setting color scheme for visualizations
+#' Set color scheme for visualizations
 #'
 #' @description
-#' This function defines a color scheme for visualizations in the {fHMM} package.
+#' This helper function defines a color scheme for visualizations in the 
+#' \{fHMM\} package.
 #'
 #' @param controls
 #' An object of class \code{fHMM_controls}.
+#' It can be created with \code{\link{set_controls}}.
 #' @param colors
-#' Either \code{NULL} or a character vector of color names or hexadecimal RGB
-#' triplets.
+#' Either \code{NULL} (default) or a \code{character} vector of color names or 
+#' hexadecimal RGB triplets.
 #'
 #' @return
 #' An object of class \code{fHMM_colors}, which is:
 #' \itemize{
-#'   \item for \code{controls$hierarchy == FALSE} a vector of length
-#'         \code{controls$states} of color codes,
-#'   \item for \code{controls$hierarchy == TRUE} a list of
+#'   \item for \code{controls$hierarchy == FALSE} a \code{character} vector of 
+#'         length \code{controls$states} of color codes,
+#'   \item for \code{controls$hierarchy == TRUE} a \code{list} of
 #'         \itemize{
-#'           \item a vector of length  \code{controls$states[1]} and
-#'           \item a matrix of dimensions \code{controls$states} of color codes.
+#'           \item a \code{character} vector of length  \code{controls$states[1]} and
+#'           \item a \code{character} matrix of dimensions \code{controls$states}
 #'         }
+#'         with color codes.
 #' }
 #'
 #' @examples
+#' \dontrun{
 #' controls <- set_controls()
-#' fHMM:::fHMM_colors(controls, colors = c("red", "blue"))
+#' fHMM_colors(controls, colors = c("red", "blue"))
+#' }
 #' 
 #' @keywords 
 #' internal
@@ -34,18 +39,19 @@ fHMM_colors <- function(controls, colors = NULL) {
 
   ### check inputs
   if (!inherits(controls,"fHMM_controls")) {
-    stop("'controls' must be of class 'fHMM_controls'.")
+    stop("'controls' must be of class 'fHMM_controls'.", call. = FALSE)
   }
   if (is.null(colors)) {
     colors <- c("darkgreen", "green", "yellow", "orange", "red", "darkred")
   }
   if (!is.character(colors)) {
-    stop("'colors' must be a character vector.")
+    stop("'colors' must be a character vector.", call. = FALSE)
   }
   for (col in colors) {
     out <- tryCatch(is.matrix(grDevices::col2rgb(col)), error = function(e) FALSE)
     if (out == FALSE) {
-      stop("'", col, "' in 'colors' is not a valid color representation.")
+      stop("'", col, "' in 'colors' is not a valid color representation.",
+           call. = FALSE)
     }
   }
 
